@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.91';
+$Geo::Address::Formatter::VERSION = '1.92';
 use strict;
 use warnings;
 use feature qw(say);
@@ -705,8 +705,7 @@ sub _render_template {
 sub _replace_template_lambdas {
     my $self          = shift;
     my $template_text = shift;
-    my $rand_id = sprintf('%010d', rand()* 10_000_000);
-    $template_text =~ s!\Q{{#first}}\E(.+?)\Q{{/first}}\E!FIRSTSTART_${rand_id}${1}FIRSTEND_${rand_id}!g;
+    $template_text =~ s!\Q{{#first}}\E(.+?)\Q{{/first}}\E!FIRSTSTART${1}FIRSTEND!g;
     return $template_text;
 }
 
@@ -714,7 +713,7 @@ sub _replace_template_lambdas {
 sub _evaluate_template_lamdas {
     my $self = shift;
     my $text = shift;
-    $text =~ s!FIRSTSTART_\d+\s*(.+?)\s*FIRSTEND_\d+!_select_first($1)!segx;
+    $text =~ s!FIRSTSTART\s*(.+?)\s*FIRSTEND!_select_first($1)!seg;
     return $text;
 }
 
@@ -753,7 +752,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.91
+version 1.92
 
 =head1 SYNOPSIS
 
